@@ -10,7 +10,7 @@
 #include "contactdefaultactions.h"
 #include "contactviewer.h"
 
-#include <item.h>
+#include <Akonadi/Item>
 using namespace Akonadi;
 
 #include <KConfig>
@@ -21,10 +21,10 @@ using namespace Akonadi;
 #include <QPushButton>
 #include <QVBoxLayout>
 
-class Q_DECL_HIDDEN ContactViewerDialog::Private
+class Akonadi::ContactViewerDialogPrivate
 {
 public:
-    Private(ContactViewerDialog *parent)
+    explicit ContactViewerDialogPrivate(ContactViewerDialog *parent)
         : q(parent)
     {
     }
@@ -53,7 +53,7 @@ public:
 
 ContactViewerDialog::ContactViewerDialog(QWidget *parent)
     : QDialog(parent)
-    , d(new Private(this))
+    , d(new ContactViewerDialogPrivate(this))
 {
     setWindowTitle(i18nc("@title:window", "Show Contact"));
     auto mainLayout = new QVBoxLayout(this);
@@ -83,7 +83,6 @@ ContactViewerDialog::ContactViewerDialog(QWidget *parent)
 ContactViewerDialog::~ContactViewerDialog()
 {
     d->writeConfig();
-    delete d;
 }
 
 Akonadi::Item ContactViewerDialog::contact() const
