@@ -1,7 +1,7 @@
 /*
     This file is part of Contact Editor.
 
-    SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -16,11 +16,9 @@ ContactEditorComboBox::ContactEditorComboBox(QWidget *parent)
     setSizeAdjustPolicy(QComboBox::AdjustToContents);
 }
 
-ContactEditorComboBox::~ContactEditorComboBox()
-{
-}
+ContactEditorComboBox::~ContactEditorComboBox() = default;
 
 QSize ContactEditorComboBox::minimumSizeHint() const
 {
-    return QSize(150, QComboBox::minimumSizeHint().height());
+    return {150, QComboBox::minimumSizeHint().height()};
 }
